#' Plots a network of interaction metrics
#'
#' @param tissue_graphs tbl_graph generated by tissue_multi_graph
#' @param layout layout to be passed to ggraph. Default: kk.
#' Some useful alternative is dh.
#' 
#' @import ggraph
#' @import igraph
#'
#' @export

print_multi_graphs = function(tissue_graphs, layout = "kk", ... ) {
    
    gg = tissue_graphs %>% 
        ggraph(layout = layout, ...) +
        geom_edge_parallel2(aes(edge_colour = int_type, edge_linetype = method),
                            width = 0.5, 
                            start_cap = circle(0), 
                            end_cap = circle(0), 
                            sep = unit(0.8, 'mm'))  +
        ## scale_edge_color_manual(values = c("darkblue", "darkred", "black"), 
        ##                         limits = c("neg", "pos", "MI"),
        ##                         labels = c("negative", "positive", "MI")) +
        scale_edge_color_manual(values = c("dodgerblue3", "red3", "snow4"), 
                                limits = c("neg", "pos", "MI"),
                                labels = c("negative", "positive", "MI")) + 
        scale_edge_linetype_manual(
            limits = c("CoDa", "cooccurrence", "MI", "Spearman"),
            values = c("solid", "dotted", "dotdash", "dashed"),
            labels = c("CoDa", "cooccurrence", "MI", "Spearman")) +
        ## geom_node_point(size = 10, color = "gray30") + 
        geom_node_label(aes(label = name)) + 
        guides(edge_color=guide_legend(title="Interaction type"),
               edge_linetype = guide_legend(title = "Method")) +
        theme_graph(base_family = "sans") +
        theme(panel.background = element_rect(fill = "whitesmoke", color = NA))
        
    return(gg)
}
