% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.R
\name{get_surv_best_model}
\alias{get_surv_best_model}
\title{Running batch survival analysis tests for a set of interactions. Returns a
list of cox regression outputs with the best selected model. If the tissue
supports a survival effect for a given interaction, then this model is selected.
Among several models, the one with the lowest loglik is .}
\usage{
get_surv_best_model(
  sig.sig.tissues.matrix,
  dataset,
  clin.df,
  param.list,
  min.sample.fraction = 0,
  filename = NULL,
  rm.non.sig.sheets = TRUE,
  return.only.sig = TRUE,
  sig.threshold = 0.05,
  split.by.tissue = TRUE
)
}
\arguments{
\item{sig.sig.tissues.matrix}{A matrix with rows and columns with signatures,
and the elements are comma-separated tissue names where that interaction is
observed.}

\item{dataset}{The signature values for all samples. E.g. PCAWG.full.subset.ann}

\item{clin.df}{The dataframe with clinical info.}

\item{filename}{The xlsx file where the models should be written.}

\item{rm.non.sig.sheets}{If TRUE, then the interactions in which the best model
doesn't show a significant interaction effect are removed from the sheet.}

\item{sig.threshold}{Defines the significant threshold.}

\item{split.by.tissue}{If TRUE for a given interaction the models are fit individually.}

\item{with.total.muts}{If TRUE the total number of mutations in the samples will
be provided as a covariate to the model. Default: TRUE}

\item{tmb.logged}{If TRUE the tumor mutational burden will be logged.
Default: TRUE}

\item{binary.status}{If TRUE, the model will compare samples with both signatures
with all the other samples having either of the signatures or none. Default:
FALSE}
}
\description{
Running batch survival analysis tests for a set of interactions. Returns a
list of cox regression outputs with the best selected model. If the tissue
supports a survival effect for a given interaction, then this model is selected.
Among several models, the one with the lowest loglik is .
}
